import argparse
import logging
import sys
from functools import reduce

from .activation import *
from .main import parse, extract, mutate_url


def print_info(info):
    logging.info('Result\n' + '-' * 40)
    for key, value in info.items():
        print('%s: %s' % (key, value))


def get_site_response(url, cookies=None, headers={}):
    page, status = parse(url, cookies, headers=headers, timeout=10)
    if status != 200:
        logging.info('Answer code {}, something went wrong'.format(status))
    return page


def run():
    parser = argparse.ArgumentParser(description='Extract accounts\' identifiers from pages.')
    parser.add_argument('--url', help='url to parse')
    parser.add_argument('--cookies', default='', help='cookies to make http requests with auth')
    parser.add_argument('-v', '--verbose', action='store_true', help='display verbose information')
    parser.add_argument('-d', '--debug', action='store_true', help='display debug information')
    parser.add_argument('--file', action='store_true', help='load from file instead of URL')
    parser.add_argument('--activation', type=str, help='use certain type of request activation')

    args = parser.parse_args()

    log_level = logging.ERROR
    if args.verbose:
        log_level = logging.INFO
    elif args.debug:
        log_level = logging.DEBUG

    logging.basicConfig(level=log_level, format='-' * 40 + '\n%(levelname)s: %(message)s')

    headers = {}
    if args.activation:
        cookies, headers = globals().get(args.activation)(args.cookies)
        logging.debug(cookies)
        logging.debug(headers)

    # load from file
    if args.file:
        page = open(args.file).read()
        info = extract(page)
        if info:
            print_info(info)
    # load from url(s)
    elif args.url:
        # (url, headers)
        reqs = [(args.url, set())]
        mutations = mutate_url(args.url)
        if mutations:
            reqs += list(mutations)

        for req in reqs:
            url, add_headers = req

            print(f'Analyzing URL {url}...')
            url_headers = dict(headers)
            url_headers.update(add_headers)

            page = get_site_response(url, args.cookies, url_headers)
            info = extract(page)
            if info:
                print_info(info)


if __name__ == '__main__':
    run()



import math
import re
import requests
from datetime import datetime

def check_empty_object(res):
    return res if res or type(res) == bool else None


def extract_facebook_uid(link):
    avatar_re = re.search(r'graph.facebook.com/(\w+)/picture', link)
    if avatar_re:
        return avatar_re.group(1)
    return None


def get_yandex_profile_pic(default_avatar_id):
    url = 'https://avatars.mds.yandex.net/get-yapic/0/0-0/islands-300'
    if default_avatar_id:
        default_avatar_id = default_avatar_id.replace('user_avatar/yapic/', '')
        url = f'https://avatars.mds.yandex.net/get-yapic/{default_avatar_id}/islands-200'
    return url

def decode_ya_str(val):
    try:
        return val.encode('iso-8859-1').decode('utf-8')
    except:
        return val


def enrich_link(html_url):
    fixed_url = html_url.lstrip('/')
    if fixed_url and not fixed_url.startswith('http'):
        fixed_url = 'https://' + fixed_url
    return fixed_url


def timestamp_to_datetime(t):
    if not t:
        return ''
    elif len(str(t)) < 10:
        t = math.floor(datetime.today().timestamp()) - t

    return datetime.fromtimestamp(int(t))


def extract_digits(text):
    digits_re = re.search(r'\d+', text)
    if digits_re:
        return digits_re[0]
    return ''


def get_ucoz_email(text):
    if text != 'Адрес скрыт':
        return text
    return ''


def get_ucoz_userlink(user_dom_node):
    prompt = user_dom_node.next_sibling.next_sibling.get('onclick')
    user_link = prompt.split("'")[-2]
    return user_link


def get_ucoz_domain(user_dom_node):
    return get_ucoz_userlink(user_dom_node).rsplit('/', 2)[0]


def get_ucoz_image(dom):
    url = dom.find('span', class_='user_avatar').find('img').get('src')
    if url.startswith('http'):
        return url
    domain = get_ucoz_domain(dom.find('div', string='Пользователь:'))
    return domain + url


def get_ucoz_uid_node(dom):
    return dom.find('b', string='uID профиль') or dom.find('b', string='uNet профиль')
